[llvm-commits] CVS: llvm/lib/Support/SystemUtils.cpp

Misha Brukman brukman at cs.uiuc.edu
Thu Aug 7 16:34:15 PDT 2003


Changes in directory llvm/lib/Support:

SystemUtils.cpp updated: 1.10 -> 1.11

---
Log message:

Remove references to `bugpoint' from the now-generic system utilities.


---
Diffs of the changes:

Index: llvm/lib/Support/SystemUtils.cpp
diff -u llvm/lib/Support/SystemUtils.cpp:1.10 llvm/lib/Support/SystemUtils.cpp:1.11
--- llvm/lib/Support/SystemUtils.cpp:1.10	Thu Aug  7 16:28:50 2003
+++ llvm/lib/Support/SystemUtils.cpp	Thu Aug  7 16:33:33 2003
@@ -37,17 +37,18 @@
 }
 
 
-// FindExecutable - Find a named executable, giving the argv[0] of bugpoint.
-// This assumes the executable is in the same directory as bugpoint itself.
-// If the executable cannot be found, return an empty string.
+// FindExecutable - Find a named executable, giving the argv[0] of program being
+// executed. This allows us to find another LLVM tool if it is built into the
+// same directory, but that directory is neither the current directory, nor in
+// the PATH.  If the executable cannot be found, return an empty string.
 //
 std::string FindExecutable(const std::string &ExeName,
-			   const std::string &BugPointPath) {
+			   const std::string &ProgramPath) {
   // First check the directory that bugpoint is in.  We can do this if
   // BugPointPath contains at least one / character, indicating that it is a
   // relative path to bugpoint itself.
   //
-  std::string Result = BugPointPath;
+  std::string Result = ProgramPath;
   while (!Result.empty() && Result[Result.size()-1] != '/')
     Result.erase(Result.size()-1, 1);
 
@@ -56,8 +57,8 @@
     if (isExecutableFile(Result)) return Result; // Found it?
   }
 
   // Okay, if the path to bugpoint didn't tell us anything, try using the PATH
   // environment variable.
   const char *PathStr = getenv("PATH");
   if (PathStr == 0) return "";
 
@@ -56,8 +57,8 @@
   }
 
-  // Okay, if the path to bugpoint didn't tell us anything, try using the PATH
-  // environment variable.
+  // Okay, if the path to the program didn't tell us anything, try using the
+  // PATH environment variable.
   const char *PathStr = getenv("PATH");
   if (PathStr == 0) return "";





More information about the llvm-commits mailing list